# Security Policy

## Supported Versions

Versions of DCSpy are currently being supported with security updates.

| Version | Supported          |
|---------|--------------------|
| 1.6.x   | :white_check_mark: |
| 1.5.x   | :white_check_mark: |
| <1.4.x  | :x:                |

## Reporting a Vulnerability

Use internal issues.
